import os
import json
import time

LOCALAPP_DATA = os.getenv('LOCALAPPDATA')
PACKAGE_PATH = os.path.join(LOCALAPP_DATA, 'Packages', 'Microsoft.WindowsTerminal_8wekyb3d8bbwe')
SETTINGS_PATH = os.path.join(PACKAGE_PATH, 'LocalState', 'settings.json')

# def modify_font(count):
#     font_size = 12.0 if count%2==0 else 0.0
#     font_weight = 'normal' if count%2==0 else 'extra-light'
#     set_font_size(font_size, font_weight)
    
def set_font_size(font_size_new: float, font_weight: str) -> str:
    try:
        if os.path.exists(SETTINGS_PATH):
            with open(SETTINGS_PATH, "r") as file: 
                settings_content = json.load(file)
                
            settings_content["profiles"]["defaults"]["font"]["size"] = font_size_new
            settings_content["profiles"]["defaults"]["font"]["weight"] = str(font_weight)
            
            with open(SETTINGS_PATH, "w") as file:
                json.dump(settings_content, file)
            
            return "Success"

        else:
            return "Settings file not found."
        
    except Exception as e:
        return f"An exception occurred {e}"

    
count = 0
while 1:
    print(set_font_size(12.0 if count%2==0 else 0.0, 'normal' if count%2==0 else 'extra-light'))
    time.sleep(1)
    print(count)


import os
import time
import json
import pkg_resources
import google.generativeai as genai
from queky.constants import SETTINGS_PATH, GOOGLE_API_KEY, JSON_FILE

genai.configure(api_key=GOOGLE_API_KEY)

def path_convertor(path: str) -> str:
        try:
            return pkg_resources.resource_filename('queky', path)
        except FileNotFoundError and ModuleNotFoundError:
            return path
        
def set_terminal_opacity(transparent: bool = True) -> str:
    print(f"{'Restoring' if not transparent else 'Modifying'} terminal opacity...")
    
    opacity_value = 0 if transparent else 100
    
    try:
        if os.path.exists(SETTINGS_PATH):
            with open(SETTINGS_PATH, 'r') as f:
                settings_content = json.load(f)
            
            opacity = int(settings_content["profiles"]["defaults"]["opacity"])
            
            if opacity != opacity_value:
                with open(SETTINGS_PATH, "r") as file: 
                    settings_content = json.load(file)
                    
                settings_content["profiles"]["defaults"]["opacity"] = opacity_value
                
                with open(SETTINGS_PATH, "w") as file: 
                    json.dump(settings_content, file)
            
            return "Success"

        else:
            return "Settings file not found."
        
    except Exception as e:
        return f"An exception occurred {e}"
    
def set_font_size(font_size_new: float, font_weight: str) -> str:
    try:
        if os.path.exists(SETTINGS_PATH):
            with open(SETTINGS_PATH, "r") as file: 
                settings_content = json.load(file)
                
            settings_content["profiles"]["defaults"]["font"]["size"] = font_size_new
            settings_content["profiles"]["defaults"]["font"]["weight"] = font_weight
            
            with open(SETTINGS_PATH, "w") as file:
                json.dump(settings_content, file)
            
            return "Success"

        else:
            return "Settings file not found."
        
    except Exception as e:
        return f"An exception occurred {e}"    

def is_api_present() -> bool:
    try:
        with open(JSON_FILE, "r") as file:
            data = json.load(file)
        api_key = data.get("GOOGLE_API_KEY")
        return False if api_key=="" else api_key
    except FileNotFoundError:
        return False
    except Exception as e:
        print(f"An unexpected error occurred: {e}")
        return False
    
def gemini_answers(question_string: str) -> str:
    try:
        model = genai.GenerativeModel('gemini-pro')
        response = model.generate_content(question_string)
        return response.candidates[0].content.parts[0].text
    except Exception as e:
        return f"An unexpected error occurred: {e}"


if __name__=="__main__":
    while 1:
        set_terminal_opacity(transparent=True)
        time.sleep(2)
        set_terminal_opacity(transparent=False)
        time.sleep(2)


import os
import json
import pkg_resources

LOCALAPP_DATA = os.getenv('LOCALAPPDATA')
PACKAGE_PATH = os.path.join(LOCALAPP_DATA, 'Packages', 'Microsoft.WindowsTerminal_8wekyb3d8bbwe')
SETTINGS_PATH = os.path.join(PACKAGE_PATH, 'LocalState', 'settings.json')

JSON_FILE = pkg_resources.resource_filename('queky', 'assets/data.json')

INSTRUCTIONS = """
I am going to pass you a few MCQ questions. Your job is to identify the questions and respond with just the correct answer and the answer text: 

Here is an example for what I am expecting:
Q1. B) Waltuh

Note: 
1. In case you cannot identify the questions, you can respond with 'Please paste the questions again.'
2. Strictly do not give any sort of explanation.

Your questions are as follows:
"""

with open(JSON_FILE, "r") as file:
    data = json.load(file)
    GOOGLE_API_KEY = data.get("GOOGLE_API_KEY")


import sys
import time
import json
import argparse
import pyperclip
import subprocess
import pyautogui as pg

from queky.constants import JSON_FILE
from queky.utils import gemini_answers, set_terminal_opacity, is_api_present

count = 0

def modify_env(transparent: bool = True) -> None:
    set_terminal_opacity(transparent)
    
    print("\033[H\033[J")
    
    pg.press('f11')
    time.sleep(0.05)
    pg.hotkey('fn', 'f11')
    time.sleep(0.05)
    pg.press('f11')
    
    print("\033[H\033[J")

def fetch_input() -> None:
    user_input = input("\n<<< press enter to paste >>>\n")
    print("\033[H\033[J")
    
    if user_input == "":
        clipboard_content = pyperclip.paste()
        answers = gemini_answers(clipboard_content)
        print(answers.replace('\n\n', '\n'))

    elif user_input == "exit":
        modify_env(transparent=False)
        sys.exit(0)
    elif user_input == "cls" or user_input == "clear":
        print("\033[H\033[J")


def main():
    parser = argparse.ArgumentParser(description="hey wassup lol :3")
    parser.add_argument("-r", "--reset", action="store_true", help="reset api key.")

    args = parser.parse_args()

    if not any(vars(args).values()):
        try:
            if not is_api_present():
                api_key = str(input("Gemini API key: "))
                
                if len(api_key) < 38:
                    print("Invalid API key.")
                    sys.exit(0)

                with open(JSON_FILE, "r") as file:
                    data = json.load(file)
                    
                data["GOOGLE_API_KEY"] = api_key.strip()
                
                with open(JSON_FILE, "w") as file: 
                    json.dump(data, file)
                    
                print("API key saved successfully.")
                subprocess.run(["qk"])
                
            else:
                _ = modify_env(True)

                while True:
                    user_input = input("\n<<< press enter to paste >>>\n")
                    print("\033[H\033[J")
                    
                    if user_input == "":
                        clipboard_content = pyperclip.paste()
                        answers = gemini_answers(clipboard_content)
                        print(answers.replace('\n\n', '\n'))

                    elif user_input == "exit":
                        modify_env(transparent=False)
                        sys.exit(0)
                    elif user_input == "cls" or user_input == "clear":
                        print("\033[H\033[J")
                        
                    else:
                        break
                    
        except KeyboardInterrupt:
            modify_env(transparent=False)
            sys.exit(0)
            
        except Exception as e:
            print(f"An unexpected error occurred: {e}")
            modify_env(transparent=False)
            sys.exit(0)
            
    elif args.reset:
        with open(JSON_FILE, "r") as file: data = json.load(file)
        data["GOOGLE_API_KEY"] = ""
        with open(JSON_FILE, "w") as file: json.dump(data, file)
            
        print("API key reset successfully.")
        subprocess.run(["qk"])
        
if __name__ == "__main__":
    main()


from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="queky",
    version="0.1.2.1",
    author="Pablo Escobar",
    description="Si Un Problema Puede Solucionarse, Entonces No Vale La Pena Preocuparse Por El.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["pyperclip", "google-generativeai", "pyautogui"],
    entry_points={
        "console_scripts": [
            "qk=queky.main:main",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_data={'queky': ['assets/*.json']},
    include_package_data=True,
    license="MIT"
)


import keyboard

def capslock_listener():
    capslock_pressed = False

    def on_key_event(event):
        nonlocal capslock_pressed
        if keyboard.is_pressed('capslock'):
            if event.event_type == keyboard.KEY_DOWN:
                capslock_pressed = True
            elif event.event_type == keyboard.KEY_UP:
                capslock_pressed = False
    
    keyboard.on_press(on_key_event)
    keyboard.wait('esc')
    
    return capslock_pressed

while True:
    print(capslock_listener())
    # if capslock_listener():
    #     print("Caps Lock pressed")